"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const cloud_function_1 = tslib_1.__importDefault(require("../../util/cloud-function"));
const core_1 = require("@oclif/core");
const util_1 = require("../../util");
class Functions extends core_1.Command {
    isValidPort(input) {
        const port = Number(input);
        return Number.isInteger(port) && port >= 0 && port <= 65535;
    }
    async init() {
        const { flags } = await this.parse(Functions);
        const projectBasePath = flags['data-dir'];
        const logger = new util_1.Logger({ projectBasePath });
        this.log = logger.log.bind(logger);
        const port = process.env.PORT || flags.port;
        if (!this.isValidPort(port)) {
            this.log('Invalid port number. Please provide a valid port number between 0 and 65535.', 'error');
            this.exit(1);
        }
        this.sharedConfig = {
            projectBasePath,
            port: Number(port),
        };
    }
    async run() {
        await new cloud_function_1.default(this.sharedConfig.projectBasePath).serveCloudFunctions(this.sharedConfig.port);
    }
}
exports.default = Functions;
Functions.description = 'Serve cloud functions';
Functions.examples = [
    '$ csdx launch:functions',
    '$ csdx launch:functions --port=port',
    '$ csdx launch:functions --data-dir <path/of/current/working/dir>',
    '$ csdx launch:functions --data-dir <path/of/current/working/dir> -p "port number"',
];
Functions.flags = {
    port: core_1.Flags.string({
        char: 'p',
        default: '3000',
        description: 'Port number',
    }),
    'data-dir': core_1.Flags.string({
        char: 'd',
        default: process.cwd(),
        description: 'Current working directory',
    }),
};
